@@ -9,6 +9,8 @@ import (
 	"testing"
 	"time"
 
+	addonv1alpha1 "github.com/open-cluster-management/api/addon/v1alpha1"
+	addonfake "github.com/open-cluster-management/api/client/addon/clientset/versioned/fake"
 	fakeworkclient "github.com/open-cluster-management/api/client/work/clientset/versioned/fake"
 	clusterv1 "github.com/open-cluster-management/api/cluster/v1"
 	workv1 "github.com/open-cluster-management/api/work/v1"
@@ -16,6 +18,9 @@ import (
 	fakeconfigclient "github.com/open-cluster-management/submariner-addon/pkg/client/submarinerconfig/clientset/versioned/fake"
 	testinghelpers "github.com/open-cluster-management/submariner-addon/pkg/helpers/testing"
 
+	submarinerv1alpha1 "github.com/submariner-io/submariner-operator/apis/submariner/v1alpha1"
+	submarinermv1 "github.com/submariner-io/submariner/pkg/apis/submariner.io/v1"
+
 	"github.com/openshift/library-go/pkg/operator/events/eventstesting"
 
 	corev1 "k8s.io/api/core/v1"
@@ -125,6 +130,100 @@ func TestUpdateStatusCondition(t *testing.T) {
 	}
 }
 
+func TestUpdateManagedClusterAddOnStatus(t *testing.T) {
+	nowish := metav1.Now()
+	beforeish := metav1.Time{Time: nowish.Add(-10 * time.Second)}
+	afterish := metav1.Time{Time: nowish.Add(10 * time.Second)}
+
+	cases := []struct {
+		name               string
+		startingConditions []metav1.Condition
+		newCondition       metav1.Condition
+		expextedUpdated    bool
+		expectedConditions []metav1.Condition
+	}{
+		{
+			name:               "add to empty",
+			startingConditions: []metav1.Condition{},
+			newCondition:       testinghelpers.NewSubmarinerConfigCondition("test", "True", "my-reason", "my-message", nil),
+			expextedUpdated:    true,
+			expectedConditions: []metav1.Condition{testinghelpers.NewSubmarinerConfigCondition("test", "True", "my-reason", "my-message", nil)},
+		},
+		{
+			name: "add to non-conflicting",
+			startingConditions: []metav1.Condition{
+				testinghelpers.NewSubmarinerConfigCondition("two", "True", "my-reason", "my-message", nil),
+			},
+			newCondition:    testinghelpers.NewSubmarinerConfigCondition("one", "True", "my-reason", "my-message", nil),
+			expextedUpdated: true,
+			expectedConditions: []metav1.Condition{
+				testinghelpers.NewSubmarinerConfigCondition("two", "True", "my-reason", "my-message", nil),
+				testinghelpers.NewSubmarinerConfigCondition("one", "True", "my-reason", "my-message", nil),
+			},
+		},
+		{
+			name: "change existing status",
+			startingConditions: []metav1.Condition{
+				testinghelpers.NewSubmarinerConfigCondition("two", "True", "my-reason", "my-message", nil),
+				testinghelpers.NewSubmarinerConfigCondition("one", "True", "my-reason", "my-message", nil),
+			},
+			newCondition:    testinghelpers.NewSubmarinerConfigCondition("one", "False", "my-different-reason", "my-othermessage", nil),
+			expextedUpdated: true,
+			expectedConditions: []metav1.Condition{
+				testinghelpers.NewSubmarinerConfigCondition("two", "True", "my-reason", "my-message", nil),
+				testinghelpers.NewSubmarinerConfigCondition("one", "False", "my-different-reason", "my-othermessage", nil),
+			},
+		},
+		{
+			name: "leave existing transition time",
+			startingConditions: []metav1.Condition{
+				testinghelpers.NewSubmarinerConfigCondition("two", "True", "my-reason", "my-message", nil),
+				testinghelpers.NewSubmarinerConfigCondition("one", "True", "my-reason", "my-message", &beforeish),
+			},
+			newCondition:    testinghelpers.NewSubmarinerConfigCondition("one", "True", "my-reason", "my-message", &afterish),
+			expextedUpdated: false,
+			expectedConditions: []metav1.Condition{
+				testinghelpers.NewSubmarinerConfigCondition("two", "True", "my-reason", "my-message", nil),
+				testinghelpers.NewSubmarinerConfigCondition("one", "True", "my-reason", "my-message", &beforeish),
+			},
+		},
+	}
+
+	for _, c := range cases {
+		t.Run(c.name, func(t *testing.T) {
+			fakeAddOnClient := addonfake.NewSimpleClientset(&addonv1alpha1.ManagedClusterAddOn{
+				ObjectMeta: metav1.ObjectMeta{Namespace: "test", Name: "test"},
+				Status: addonv1alpha1.ManagedClusterAddOnStatus{
+					Conditions: c.startingConditions,
+				},
+			})
+
+			status, updated, err := UpdateManagedClusterAddOnStatus(
+				context.TODO(),
+				fakeAddOnClient,
+				"test", "test",
+				UpdateManagedClusterAddOnStatusFn(c.newCondition),
+			)
+			if err != nil {
+				t.Errorf("unexpected err: %v", err)
+			}
+			if updated != c.expextedUpdated {
+				t.Errorf("expected %t, but %t", c.expextedUpdated, updated)
+			}
+			for i := range c.expectedConditions {
+				expected := c.expectedConditions[i]
+				actual := status.Conditions[i]
+				if expected.LastTransitionTime == (metav1.Time{}) {
+					actual.LastTransitionTime = metav1.Time{}
+				}
+				if !equality.Semantic.DeepEqual(expected, actual) {
+					t.Errorf(diff.ObjectDiff(expected, actual))
+				}
+			}
+		})
+	}
+}
+
 func TestGenerateAndGetIPSecPSKSecret(t *testing.T) {
 	cases := []struct {
 		name            string
@@ -504,12 +603,17 @@ func TestGetClusterType(t *testing.T) {
 			managedCluster: &clusterv1.ManagedCluster{
 				ObjectMeta: metav1.ObjectMeta{
 					Name: "cluster1",
-					Labels: map[string]string{
-						"vendor": "OpenShift",
+				},
+				Status: clusterv1.ManagedClusterStatus{
+					ClusterClaims: []clusterv1.ManagedClusterClaim{
+						{
+							Name:  "product.open-cluster-management.io",
+							Value: "OpenShift",
+						},
 					},
 				},
 			},
-			expectType: ClusterTypeOCP,
+			expectType: "OpenShift",
 		},
 		{
 			name:        "cluster is not OCP",
@@ -517,8 +621,13 @@ func TestGetClusterType(t *testing.T) {
 			managedCluster: &clusterv1.ManagedCluster{
 				ObjectMeta: metav1.ObjectMeta{
 					Name: "cluster1",
-					Labels: map[string]string{
-						"vendor": "others",
+				},
+				Status: clusterv1.ManagedClusterStatus{
+					ClusterClaims: []clusterv1.ManagedClusterClaim{
+						{
+							Name:  "product.open-cluster-management.io",
+							Value: "others",
+						},
 					},
 				},
 			},
@@ -538,7 +647,7 @@ func TestGetClusterType(t *testing.T) {
 
 	for _, c := range cases {
 		t.Run(c.name, func(t *testing.T) {
-			clusterType := GetClusterType(c.managedCluster)
+			clusterType := GetClusterProduct(c.managedCluster)
 			if clusterType != c.expectType {
 				t.Errorf("expect %s, but %s", c.expectType, clusterType)
 			}
@@ -567,11 +676,14 @@ func TestGetManagedClusterInfo(t *testing.T) {
 			name: "has claims",
 			managedCluster: &clusterv1.ManagedCluster{
 				ObjectMeta: metav1.ObjectMeta{
-					Name:   "test",
-					Labels: map[string]string{"vendor": "OCP"},
+					Name: "test",
 				},
 				Status: clusterv1.ManagedClusterStatus{
 					ClusterClaims: []clusterv1.ManagedClusterClaim{
+						{
+							Name:  "product.open-cluster-management.io",
+							Value: "OpenShift",
+						},
 						{
 							Name:  "platform.open-cluster-management.io",
 							Value: "AWS",
@@ -589,7 +701,7 @@ func TestGetManagedClusterInfo(t *testing.T) {
 			},
 			expected: configv1alpha1.ManagedClusterInfo{
 				ClusterName: "test",
-				Vendor:      "OCP",
+				Vendor:      "OpenShift",
 				Platform:    "AWS",
 				Region:      "us-east-1",
 				InfraId:     "cluster-1234",
@@ -724,7 +836,7 @@ func TestApplyManifestWork(t *testing.T) {
 	for _, c := range cases {
 		t.Run(c.name, func(t *testing.T) {
 			workClient := fakeworkclient.NewSimpleClientset(c.existingWorks...)
-			err := ApplyManifestWork(context.TODO(), workClient, c.work)
+			err := ApplyManifestWork(context.TODO(), workClient, c.work, eventstesting.NewTestingEventRecorder(t))
 			if err != nil {
 				t.Errorf("expect no err, but got: %v", err)
 			}
@@ -766,6 +878,140 @@ func TestGetEnv(t *testing.T) {
 	}
 }
 
+func TestCheckSubmarinerConnections(t *testing.T) {
+	cases := []struct {
+		name              string
+		submariner        *submarinerv1alpha1.Submariner
+		validateCondation func(t *testing.T, actual metav1.Condition)
+	}{
+		{
+			name:       "no status",
+			submariner: &submarinerv1alpha1.Submariner{},
+			validateCondation: func(t *testing.T, actual metav1.Condition) {
+				if actual.Status != metav1.ConditionTrue {
+					t.Errorf("expected degraded, but failed")
+				}
+				if actual.Reason != "ConnectionsNotEstablished" {
+					t.Errorf("unexpected reason, %v", actual)
+				}
+			},
+		},
+		{
+			name: "no connections",
+			submariner: &submarinerv1alpha1.Submariner{
+				Status: submarinerv1alpha1.SubmarinerStatus{
+					Gateways: &[]submarinermv1.GatewayStatus{{Connections: []submarinermv1.Connection{}}},
+				},
+			},
+			validateCondation: func(t *testing.T, actual metav1.Condition) {
+				if actual.Status != metav1.ConditionTrue {
+					t.Errorf("expected degraded, but failed")
+				}
+				if actual.Reason != "ConnectionsNotEstablished" {
+					t.Errorf("unexpected reason, %v", actual)
+				}
+			},
+		},
+		{
+			name: "connections are not established",
+			submariner: &submarinerv1alpha1.Submariner{
+				Status: submarinerv1alpha1.SubmarinerStatus{
+					Gateways: &[]submarinermv1.GatewayStatus{
+						{
+							Connections: []submarinermv1.Connection{
+								{
+									Status: "connected",
+									Endpoint: submarinermv1.EndpointSpec{
+										ClusterID: "test1",
+										Hostname:  "test2",
+									},
+								},
+								{
+									Status: "error",
+									Endpoint: submarinermv1.EndpointSpec{
+										ClusterID: "test2",
+										Hostname:  "test2",
+									},
+								},
+							},
+						},
+					},
+				},
+			},
+			validateCondation: func(t *testing.T, actual metav1.Condition) {
+				if actual.Status != metav1.ConditionTrue {
+					t.Errorf("expected degraded, but failed")
+				}
+				if actual.Reason != "ConnectionsDegraded" {
+					t.Errorf("unexpected reason, %v", actual)
+				}
+			},
+		},
+		{
+			name: "connections are established",
+			submariner: &submarinerv1alpha1.Submariner{
+				Status: submarinerv1alpha1.SubmarinerStatus{
+					Gateways: &[]submarinermv1.GatewayStatus{
+						{
+							Connections: []submarinermv1.Connection{
+								{
+									Status: "connected",
+									Endpoint: submarinermv1.EndpointSpec{
+										ClusterID: "test",
+										Hostname:  "test",
+									},
+								},
+							},
+						},
+					},
+				},
+			},
+			validateCondation: func(t *testing.T, actual metav1.Condition) {
+				if actual.Status != metav1.ConditionFalse {
+					t.Errorf("expected undegraded, but failed")
+				}
+				if actual.Reason != "ConnectionsEstablished" {
+					t.Errorf("unexpected reason, %v", actual)
+				}
+			},
+		},
+	}
+
+	for _, c := range cases {
+		t.Run(c.name, func(t *testing.T) {
+			c.validateCondation(t, CheckSubmarinerConnections("test", c.submariner))
+		})
+	}
+}
+
+func TestGernerateBrokerName(t *testing.T) {
+	cases := []struct {
+		name           string
+		clusterSetName string
+		expectedLength int
+	}{
+		{
+			name:           "short name",
+			clusterSetName: "test-clustr-set",
+			expectedLength: len("test-clustr-set-broker"),
+		},
+		{
+			name:           "long name",
+			clusterSetName: "clusterset-geographically-distributed-workloads-long-set-name",
+			expectedLength: 63,
+		},
+	}
+
+	for _, c := range cases {
+		t.Run(c.name, func(t *testing.T) {
+			actual := GernerateBrokerName(c.clusterSetName)
+			if len(actual) != c.expectedLength {
+				t.Errorf("expected %d, but: %d, %q", c.expectedLength, len(actual), actual)
+			}
+		})
+	}
+}
+
 func newUnstructured(apiVersion, kind, namespace, name string, content map[string]interface{}) *unstructured.Unstructured {
 	object := &unstructured.Unstructured{
 		Object: map[string]interface{}{
