@@ -1,7 +1,7 @@
 #!/bin/bash
 
 source scripts/clusters.sh
-k8s_version="v1.18.0"
+k8s_version="v1.20.2"
 
 if [ "$1"x = "cleanup"x ]; then
     for cluster in "${clusters[@]}"; do
@@ -97,9 +97,8 @@ function deploy_hub() {
 
     # add master apiserver to submariner-addon deployment
     cat <<EOF >> ${submariner_deployment}
-        env:
-        - name: BROKER_API_SERVER
-          value: "${master_ip}:6443"
+          - name: BROKER_API_SERVER
+            value: "${master_ip}:6443"
 EOF
     kubectl apply -k ${submariner_deploy_dir}/config/manifests
 }
@@ -194,13 +193,12 @@ function accept_managed_cluster() {
 apiVersion: submarineraddon.open-cluster-management.io/v1alpha1
 kind: SubmarinerConfig
 metadata:
-  name: subconfig
+  name: submariner
   namespace: ${cluster}
 spec:
   subscriptionConfig:
     source: operatorhubio-catalog
     sourceNamespace: olm
-    startingCSV: submariner.v0.8.1
 EOF
 }
 
